@@ -1,4 +1,3 @@
-
 from mnemocards import greet
 from mnemocards._argument_parser import parse_args
 from mnemocards.github import github
@@ -7,6 +6,8 @@ from mnemocards.pull import pull
 from mnemocards.push import push
 from mnemocards.clean import clean
 from mnemocards.import_command import import_command
+from mnemocards.maketsv import make_tsv
+from mnemocards.utils import generate_card_uuid
 
 
 def main():
@@ -28,8 +29,11 @@ def main():
         clean(args.collection_path, args.profile_name)
     elif args.command == "hi":
         greet()
+    elif args.command == "maketsv":
+        make_tsv(args)
+    elif args.command == "id":
+        generate_card_uuid()
 
 
 if __name__ == "__main__":
     main()
-
